# Plot themes for the Leibniz Institute for the German Language (IDS)
---

## Description
The package provides a collection themes for different plotting libraries, following the corporate design of the Leibniz Institute for the German Language (IDS) in Mannheim (Germany).

## Installation

1. Download and install the Fira Sans Condensed font, for example from [Google Fonts](https://fonts.google.com/specimen/Fira+Sans+Condensed?preview.text_type=custom)

2. Install idsThemeR from its gerrit/git repository:

    ```R
    library(devtools)
    install_git("https://korap.ids-mannheim.de/gerrit/IDS-Mannheim/idsThemeR")
    ```

## Examples
### [highcharter](https://cran.r-project.org/package=highcharter) – light with IDS departments palette

```R
library(tidyverse)
library(highcharter)
library(idsThemeR)
library(htmlwidgets)
hc <- highcharts_demo() %>%
   hc_add_theme(hc_theme_ids_light(palette = "ids"))
print(hc)
saveWidget(hc, file="highchart.html")
```
![](./man/figures/Readme-Example-1.png)<!-- -->

### ggplot2 – dark with default colour palette

```R
library(ggplot2)
library(idsThemeR)

dtemp <- data.frame(months = factor(rep(substr(month.name, 1, 3), 4),
                                    levels = substr(month.name, 1, 3)),
                    city = rep(c("Tokyo", "New York", "Berlin", "London"),
                               each = 12),
                    temp = c(7.0, 6.9, 9.5, 14.5, 18.2, 21.5,
                             25.2, 26.5, 23.3, 18.3, 13.9, 9.6,
                             -0.2, 0.8, 5.7, 11.3, 17.0, 22.0,
                             24.8, 24.1, 20.1, 14.1, 8.6, 2.5,
                             -0.9, 0.6, 3.5, 8.4, 13.5, 17.0,
                             18.6, 17.9, 14.3, 9.0, 3.9, 1.0,
                             3.9, 4.2, 5.7, 8.5, 11.9, 15.2,
                             17.0, 16.6, 14.2, 10.3, 6.6, 4.8))

ggplot(dtemp, aes(x = months, y = temp, group = city, color = city)) +
  geom_line() +
  geom_point(size = 1.1) +
  ggtitle("Monthly Average Temperature") +
  theme_ids(style="dark") +
  scale_colour_ids()
```
![](./man/figures/Readme-Example-2.png)<!-- -->

### ggplot2 – light with IDS departments palette

```R
dtemp <- data.frame(Months = factor(rep(substr(month.name, 1, 3), 4),
                                    levels = substr(month.name, 1, 3)),
                    City = rep(c("Tokyo", "New York", "Berlin", "London"),
                               each = 12),
                    Temperature = c(7.0, 6.9, 9.5, 14.5, 18.2, 21.5,
                             25.2, 26.5, 23.3, 18.3, 13.9, 9.6,
                             -0.2, 0.8, 5.7, 11.3, 17.0, 22.0,
                             24.8, 24.1, 20.1, 14.1, 8.6, 2.5,
                             -0.9, 0.6, 3.5, 8.4, 13.5, 17.0,
                             18.6, 17.9, 14.3, 9.0, 3.9, 1.0,
                             3.9, 4.2, 5.7, 8.5, 11.9, 15.2,
                             17.0, 16.6, 14.2, 10.3, 6.6, 4.8))

ggplot(dtemp, aes(x = Months, y = Temperature, group = City, color = City)) +
  geom_line() +
  geom_point(size = 1.1) +
  ggtitle("Monthly Average Temperature", subtitle="Source: WorldClimate.com") +
  theme_ids() +
  scale_colour_ids(palette = "ids")
```
![](./man/figures/Readme-Example-3.png)<!-- -->

### Stacked bars with ggplot2 light and default colours saved as png
```R
subkategorien <- data.frame(Kategorie = rep(c("Ressource A", "Ressource B",
                                              "Ressource C"), each = 3),
                            Subkategorie = rep(c("Sub1", "Sub2", "Sub3"), 3),
                            Wert = rnorm(n = 9, mean = 10000, sd = 2500))

ggplot(subkategorien, aes(x = Kategorie, y = Wert, fill = Subkategorie)) +
  geom_col() +
  labs(x = "<x-Achsen-Beschriftung>",
       y = "<y-Achsen-Beschriftung>",
       title = "<Titel>",
       subtitle = "<optionaler Untertitel>") +
#  theme(axis.text.x = element_text(angle = 45, hjust = 1)) +
  theme_ids() +
  scale_fill_ids()
ggsave("./man/figures/stacked_bars.png", width = 70 * .pt, height = 40 *.pt, units = "mm", dpi = 600)
```
![](./man/figures/stacked_bars.png)<!-- -->

### Grouped bars with ggplot2 light and default colours saved as png
```R
subkategorien <- data.frame(Kategorie = rep(c("Ressource A", "Ressource B",
                                              "Ressource C"), each = 3),
                            Subkategorie = rep(c("Sub1", "Sub2", "Sub3"), 3),
                            Wert = rnorm(n = 9, mean = 10000, sd = 2500))

ggplot(subkategorien, aes(x = Kategorie, y = Wert, fill = Subkategorie)) +
  geom_col(position = position_dodge()) +
  labs(x = "<x-Achsen-Beschriftung>",
       y = "<y-Achsen-Beschriftung>",
       fill = "<Legendenbeschriftung>",
       title = "<Titel>",
       subtitle = "<optionaler Untertitel>") +
#  theme(axis.text.x = element_text(angle = 45, hjust = 1)) +
  theme_ids() +
  scale_fill_ids()
ggsave("./man/figures/grouped_bars.png", width = 70 * .pt, height = 40 *.pt, units = "mm", dpi = 600)
```
![](./man/figures/grouped_bars.png)<!-- -->

## Palettes
### Default: Adapted D3 based Palette
```R
library(scales)
show_col(ids_pal()(20))
```
![](./man/figures/paletteD3.png)<!-- -->

### IDS Departments Palette
```R
library(scales)
show_col(ids_pal(palette="ids")(20))
```
![](./man/figures/palette1.png)<!-- -->

## Demos

More elaborate R scripts demonstrating the use of the package can be found in the [demo](demo) folder.

## Changes
See [Changelog](./Changelog.md)

## Development and License

**Authors**: [Marc Kupietz](http://www1.ids-mannheim.de/zfo/personal/kupietz/)

Copyright (c) 2020, [Leibniz Institute for the German Language](http://www.ids-mannheim.de/), Mannheim, Germany

This package is developed as part of the [KorAP](http://korap.ids-mannheim.de/)
Corpus Analysis Platform at the Leibniz Institute for German Language
([IDS](http://www.ids-mannheim.de/)).

It is published under the
[BSD-2 License](LICENSE.md).

### Further Affected Licenses and Terms of Services

#### Highcharts
idsThemeR imports the [highcharter package](https://cran.r-project.org/package=highcharter) which has a dependency on Highcharts, a commercial JavaScript charting library. Highcharts offers both a commercial license as well as a free non-commercial license. Please review the licensing options and terms before using the highcharter plot options, as the `idsThemeR` license neither provides nor implies a license for Highcharts.

[Highcharts](http://highcharts.com) is a Highsoft product which is not free for commercial and governmental use.

## Contributions

Contributions are very welcome!

Your contributions should be committed via our [Gerrit server](https://korap.ids-mannheim.de/gerrit/)
to facilitate reviewing (see [Gerrit Code Review - A Quick Introduction](https://korap.ids-mannheim.de/gerrit/Documentation/intro-quick.html)).

Please note that unless you explicitly state otherwise any
contribution intentionally submitted for inclusion into this software shall –
as this software itself – be under the [BSD-2 License](LICENSE.md).
